@@ -77,7 +77,7 @@ get.ensemble <- function (ensemble) {
   }
   else if (ensemble == "all") {
     ensemble <- 2^0 + 2^1
-  }    
+  }
   else {
     stop("Invalid choice for 'ensemble' option:  ", ensemble)
   }
@@ -222,7 +222,7 @@ get.na.action <- function (na.action) {
       ## This is the high byte!
       na.action <- 2^4
       ## To recover the original functionality in which the split
-      ## statistic uses missing in-node imputed values, uncomment 
+      ## statistic uses missing in-node imputed values, uncomment
       ## the following statement:
       ## na.action <- 0
     }
@@ -463,8 +463,8 @@ get.seed <- function (seed) {
     return (statistics)
   }
   get.terminal.qualts <- function (terminal.qualts, incoming.flag) {
-    ## Convert option into native code parameter.  This 
-    ## is sensitive to incoming and outgoing data 
+    ## Convert option into native code parameter.  This
+    ## is sensitive to incoming and outgoing data
     ## (from the native code perspective).
     bits <- 0
     if (is.null(incoming.flag)) {
@@ -488,8 +488,8 @@ get.seed <- function (seed) {
     return (bits)
   }
   get.terminal.quants <- function (terminal.quants, incoming.flag) {
-    ## Convert option into native code parameter.  This 
-    ## is sensitive to incoming and outgoing data 
+    ## Convert option into native code parameter.  This
+    ## is sensitive to incoming and outgoing data
     ## (from the native code perspective).
     bits <- 0
     if (is.null(incoming.flag)) {
@@ -771,11 +771,11 @@ is.hidden.tdc.rule <-  function (user.option) {
         ## interactions.  If synthetic cuts are requested, the rule is
         ## "synthetic".  Note that division by zero is a possibility
         ## in interactions and not handled, so be careful.
-        base.learner <- get.base.learner(interact.depth = 0, synthetic.depth = 0) 
+        base.learner <- get.base.learner(interact.depth = 0, synthetic.depth = 0)
     }
     else {
         ## Check the class of the object.
-        if (class(user.option$base.learner) == "base.learner") {
+      if (inherits(user.option$base.learner, "base.learner")) {
             base.learner <- user.option$base.learner
         }
         else {
@@ -787,11 +787,11 @@ is.hidden.tdc.rule <-  function (user.option) {
   is.hidden.lot <-  function (user.option) {
     if (is.null(user.option$lot)) {
         ## Traditional non-greedy recursive growth.  Parameter hdim must be zero.
-        lot <- get.lot(hdim = 0, treesize = 0, lag = 0, strikeout = 0) 
+        lot <- get.lot(hdim = 0, treesize = 0, lag = 0, strikeout = 0)
     }
     else {
         ## Check the class of the object.
-        if (class(user.option$lot) == "lot") {
+      if (inherits(user.option$lot, "lot")) {
             lot <- user.option$lot
         }
         else {
